#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from onf_website.component.hearing import IHearingInfo
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.shared.common.interfaces import IWfSharedContent
from pyams_default_theme.shared.common.url import \
    WfSharedContentRelativeUrlAdapter as WfSharedContentRelativeUrlAdapterBase
from pyams_sequence.interfaces import ISequentialIdInfo
from pyams_skin.layer import IPyAMSUserLayer
from pyams_utils.adapter import ContextRequestAdapter, adapter_config
from pyams_utils.interfaces.url import ICanonicalURL, IRelativeURL
from pyams_utils.url import absolute_url


@adapter_config(context=(IWfSharedContent, IPyAMSUserLayer), provides=ICanonicalURL)
class WfSharedContentCanonicalURL(ContextRequestAdapter):
    """Shared content canonical URL"""

    def get_url(self, view_name=None, query=None):
        parent = None
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            parent = hearing.get_source_folder()
            if parent is None:
                parent = hearing.get_source_site()
        if parent is None:
            parent = self.request.root
        return absolute_url(parent, self.request,
                            '++oid++{0}::{1}.html'.format(
                                ISequentialIdInfo(self.context).get_base_oid().strip(),
                                self.context.content_url))


@adapter_config(context=(IWfSharedContent, IONFBaseLayer), provides=IRelativeURL)
class WfSharedContentRelativeUrlAdapter(WfSharedContentRelativeUrlAdapterBase):
    """Shared content relative URL adapter"""

    def get_url(self, display_context=None, view_name=None, query=None):
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            parent = hearing.get_source_folder()
            if parent is None:
                parent = hearing.get_source_site()
            if parent is not None:
                return super(WfSharedContentRelativeUrlAdapter, self).get_url(parent, view_name, query)
        return super(WfSharedContentRelativeUrlAdapter, self).get_url(display_context, view_name, query)
